==> react-breakpoint-toggle-1.5.0.tgz: package/lib/index.js <==
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { Component } from 'react';
import PropTypes from 'prop-types';
import ViewportResize from './viewport-resize';

var BreakpointToggle =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(BreakpointToggle, _Component);

  function BreakpointToggle(props) {
    var _this;

    _this = _Component.call(this, props) || this;
    _this.state = {};
    _this.onViewportResize = _this.onViewportResize.bind(_assertThisInitialized(_this));
    return _this;
  }

  var _proto = BreakpointToggle.prototype;

  _proto.componentDidMount = function componentDidMount() {
    ViewportResize.addListener(this.onViewportResize);
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    ViewportResize.removeListener(this.onViewportResize);
  };

  _proto.shouldComponentUpdate = function shouldComponentUpdate(nextProps, nextState) {
    return nextState.isDisplayed !== this.state.isDisplayed;
  };

  _proto.onViewportResize = function onViewportResize(width, height) {
    var _this$props = this.props,
        breakpoint = _this$props.breakpoint,
        inverse = _this$props.inverse;
    this.setState({
      isDisplayed: inverse ? width > breakpoint : width <= breakpoint
    });
  };

  _proto.render = function render() {
    var children = this.props.children;
    var isDisplayed = this.state.isDisplayed;
    return isDisplayed ? children : null;
  };

  return BreakpointToggle;
}(Component);

BreakpointToggle.displayName = 'BreakpointToggle';
BreakpointToggle.defaultProps = {
  inverse: false
};
export default BreakpointToggle;

==> react-breakpoint-toggle-1.6.0.tgz: package/lib/index.js <==
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { Component } from 'react';
import PropTypes from 'prop-types';
import ViewportResize from './viewport-resize';
var BreakpointToggle = /*#__PURE__*/function (_Component) {
  _inheritsLoose(BreakpointToggle, _Component);
  function BreakpointToggle(props) {
    var _this;
    _this = _Component.call(this, props) || this;
    _this.state = {};
    _this.onViewportResize = _this.onViewportResize.bind(_assertThisInitialized(_this));
    return _this;
  }
  var _proto = BreakpointToggle.prototype;
  _proto.componentDidMount = function componentDidMount() {
    ViewportResize.addListener(this.onViewportResize);
  };
  _proto.componentWillUnmount = function componentWillUnmount() {
    ViewportResize.removeListener(this.onViewportResize);
  };
  _proto.shouldComponentUpdate = function shouldComponentUpdate(nextProps, nextState) {
    return nextState.isDisplayed !== this.state.isDisplayed;
  };
  _proto.onViewportResize = function onViewportResize(width, height) {
    var _this$props = this.props,
      breakpoint = _this$props.breakpoint,
      inverse = _this$props.inverse;
    this.setState({
      isDisplayed: inverse ? width > breakpoint : width <= breakpoint
    });
  };
  _proto.render = function render() {
    var children = this.props.children;
    var isDisplayed = this.state.isDisplayed;
    return isDisplayed ? children : null;
  };
  return BreakpointToggle;
}(Component);
BreakpointToggle.displayName = 'BreakpointToggle';
BreakpointToggle.defaultProps = {
  inverse: false
};
export default BreakpointToggle;
